@@ -9,7 +9,7 @@
 #    Copyright (C) 1999 Francis J. Lacoste, iNsu Innovations
 #    Parts Copyright 1996-1999 by Michael J. Heins 
 #    Parts Copyright 1996-1999 by Bruce Albrecht  
-#    Parts Copyright 2001-2005 by Mark Stosberg 
+#    Parts Copyright 2001-2003 by Mark Stosberg 
 #
 #    Parts of this module are based on work by
 #    Bruce Albrecht,  contributed to
@@ -26,12 +26,12 @@ package Data::FormValidator;
 use 5.005; # for "qr" support, which isn't strictly required. 
 
 use Data::FormValidator::Results;
-use Data::FormValidator::Filters ':filters';
-use Data::FormValidator::Constraints qw(:validators :matchers);
+use Data::FormValidator::Filters (qw/:filters/);
+use Data::FormValidator::Constraints (qw/:validators :matchers/);
 
 use vars qw( $VERSION $AUTOLOAD @ISA @EXPORT_OK %EXPORT_TAGS );
 
-$VERSION = '4.49_1';
+$VERSION = '4.01';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -167,9 +167,9 @@ sub new {
 
  my $results = Data::FormValidator->check(\%input_hash, \%dfv_profile);
 
-C<check> is the recommended method to use to validate forms. It returns its results as a
+C<check> is the recommended method to use to validate forms. It returns it's results as a
 L<Data::FormValidator::Results|Data::FormValidator::Results> object.  A
-deprecated method C<validate> is also available, returning its results as an
+deprecated method C<validate> is also available, returning it's results as an
 array described below.
 
  use Data::FormValidator;
@@ -239,7 +239,7 @@ want by name later with C<check()>. Here's an example:
 
  my $dfv = Data::FormValidator->new({
     profile_1 => { # usual profile definition here },
-    profile_2 => { # another profile definition },
+    profile_1 => { # another profile definition },
  });
 
 
@@ -361,7 +361,7 @@ keys.
 Here is a very simple input profile. Examples of more advanced options are
 described below.
 
-    use Data::FormValidator::Constraints qw(:closures);
+    use Data::FormValidator::Constraints qw(:all);
 
     my $profile = {
         optional => [qw( company
@@ -480,19 +480,6 @@ object as the only parameter.
 The defaults are set shortly before the constraints are applied, and
 will be returned with the other valid data.
 
-=head2 defaults_regexp_map
-
-  defaults_regexp_map => {
-      qr/^opt_/ => 1,
-  },
-
-This is a hash reference that maps  regular expressions to default values to
-use for matching optional or required fields. 
-
-It's useful if you have generated many checkbox fields with the similiar names.
-Since checkbox fields submit nothing at all when they are not checked, it's
-useful to set defaults for them.
-
 =head2 filters
 
  # trim leading and trailing whitespace on all fields
@@ -505,9 +492,9 @@ This can be the name of a built-in filter
 (trim,digit,etc) or an anonymous subroutine which should take one parameter, 
 the field value and return the (possibly) modified value.
 
-Filters modify the data returned through the results object, so use them carefully. 
+Filters modify the data, so use them carefully. 
 
-See L<Data::FormValidator::Filters> for details on the built-in filters.
+See Data::FormValidator::Filters for details on the built-in filters.
 
 =head2 field_filters
 
@@ -537,7 +524,7 @@ match a regular expression.
 
 =head2 constraint_methods
 
- use Data::FormValidator::Constraints qw(:closures);
+ use Data::FormValidator::Constraints (qw:all);
 
  constraint_methods => {
     cc_no      => cc_number({fields => ['cc_type']}),
@@ -576,8 +563,8 @@ B<Example>:
 
  my_zipcode_field   => qr/^\d{5}$/, # match exactly 5 digits
 
-If this field is named in C<untaint_constraint_fields> or C<untaint_regexp_map>,
-or C<untaint_all_constraints> is effective, be aware of the following: If you
+If this field is named in the C<untaint_constraint_fields>, or 
+C<untaint_all_constraints> is effective, be aware of the following: If you
 write your own regular expressions and only match part of the string then
 you'll only get part of the string in the valid hash. It is a good idea to
 write you own constraints like /^regex$/. That way you match the whole string.
@@ -589,8 +576,8 @@ a subroutine reference, to supply custom code
 This will check the input and return true or false depending on the input's validity.
 By default, the constraint function recieves a L<Data::FormValidator::Results>
 object as its first argument, and the value to be validated as the second.  To
-validate a field based more inputs than just the field itself, see 
-L<VALIDATING INPUT BASED ON MULTIPLE FIELDS>.
+validate a field based more inputs than just the field itself, see C<VALIDATING
+INPUT BASED ON MULTIPLE FIELDS>.
 
 B<Examples>:
 
@@ -623,7 +610,7 @@ For more details see L<VALIDATING INPUT BASED ON MULTIPLE FIELDS>.
 
 =head2 constraint_method_regexp_map
 
- use Data::FormValidator::Constraints qw(:closures);
+ use Data::FormValidator::Constraints qw(:all);
 
  # In your profile. 
  constraint_method_regexp_map => {
@@ -650,7 +637,7 @@ may not provide untainting.
 See L<WRITING YOUR OWN CONSTRAINT ROUTINES> in the Data::FormValidator::Constraints
 documention for more information.
 
-This is overridden by C<untaint_constraint_fields> and C<untaint_regexp_map>.
+This is overridden by C<untaint_constraint_fields>
 
 =head2 untaint_constraint_fields
 
@@ -662,20 +649,6 @@ field names. The untainted data will be returned in the valid hash.
 
 This overrides the untaint_all_constraints flag.
 
-=head2 untaint_regexp_map
-
- untaint_regexp_map => [qr/some_field_\d/],
-
-Specifies that certain fields will be untained if they pass their constraints
-and match one of the regular expressions supplied. This can be set to a single
-regex, or an array reference of regexes. The untainted data will be returned
-in the valid hash.
-
-The above example would untaint the fields named C<some_field_1>, and C<some_field_2>
-but not C<some_field>. 
-
-This overrides the untaint_all_constraints flag.
-
 =head2 missing_optional_valid
 
  missing_optional_valid => 1
@@ -762,24 +735,6 @@ as providing custom messages per field, and handling multiple constraints:
 The hash that's prepared can be retrieved through the C<msgs> method
 described in the L<Data::FormValidator::Results> documentation.
 
-=head2 msgs - callback 
-
-I<This is a new feature. While it expected to be forward-compatible, it hasn't
-yet received the testing the rest of the API has.>   
-
-If the built-in message generation doesn't suit you, it is also possible to
-provide your own by specifying a code reference:
-
- msgs  =>  \&my_msgs_callback
-
-This will be called as a L<Data::FormValidator::Results> method.  It may
-receive as arguments an additional hash reference of control parameters,
-corresponding to the key names in the usually used in the C<msgs> area of the
-profile. You can ignore this information if you'd like. 
-
-If you have an alternative error message handler you'd like to share, 
-stick in the C<Data::FormValidator::ErrMsgs> and upload it to CPAN. 
-
 =head2 debug
 
 This method is used to print details about what is going on to STDERR.
@@ -816,9 +771,8 @@ Deprecated, but supported
 
 You can pass more than one value into a constraint routine.  For that, the
 value of the constraint should be a hash reference. If you are creating your
-own routines, be sure to read the section labeled 
-L<WRITING YOUR OWN CONSTRAINT ROUTINES>, 
-in the Data::FormValidator::Constraints documentation.  It describes
+own routines, be sure to read the section labeled L<WRITING YOUR OWN VALIDATION
+ROUTINES>, in the Data::FormValidator::Constraints documentation.  It describes
 a newer and more flexible syntax. 
 
 Using the original syntax, one key should be named C<constraint> and should
@@ -896,29 +850,27 @@ sub _check_profile_syntax {
         die "Invalid input profile: needs to be a hash reference\n";
 
     my %valid_profile_keys = (
-		constraint_methods           => undef,
-		constraint_method_regexp_map => undef,
-		constraint_regexp_map        => undef,
-		constraints                  => undef,
-		defaults                     => undef,
-		defaults_regexp_map          => undef,
-		dependencies                 => undef,
-		dependency_groups            => undef,
-		field_filter_regexp_map      => undef,
-		field_filters                => undef,
-		filters                      => undef,
-		missing_optional_valid       => undef,
-		msgs                         => undef,
-		optional                     => undef,
-		optional_regexp              => undef,
-		require_some                 => undef,
-		required                     => undef,
-		required_regexp              => undef,
-		untaint_all_constraints      => undef,
-		validator_packages           => undef,
-		untaint_constraint_fields    => undef,
-		untaint_regexp_map           => undef,
-		debug                        => undef,
+		constraint_methods 	          => undef,
+		constraint_method_regexp_map  => undef,
+        constraint_regexp_map=> undef,
+        constraints=> undef,
+        defaults=> undef,
+        dependencies=> undef,
+        dependency_groups=> undef,
+        field_filter_regexp_map=> undef,
+        field_filters=> undef,
+        filters=> undef,
+        missing_optional_valid=> undef,
+        msgs=> undef,
+        optional=> undef,
+        optional_regexp=> undef,
+        require_some=> undef,
+        required=> undef,
+        required_regexp => undef,
+        untaint_all_constraints=> undef,
+        validator_packages=> undef,
+        untaint_constraint_fields=> undef,
+        debug=> undef,
     );
 
     # If any of the keys in the profile are not listed as 
@@ -934,10 +886,10 @@ sub _check_profile_syntax {
     }
 
     my %valid_constraint_hash_keys = (
-        constraint        => undef,
+        constraint => undef,
         constraint_method => undef,
-        name              => undef,
-        params            => undef,
+        name => undef,
+        params => undef,
     );
 
     my @constraint_hashrefs = grep { ref $_ eq 'HASH' } values %{ $profile->{constraints} } 
@@ -1194,29 +1146,17 @@ Albrecht to the MiniVend program.
 
 =head1 BUGS
 
-Bug reports and patches are welcome. Reports which include a failing Test::More
-style test are helpful will receive priority. 
-
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Data-FormValidator> 
 
 =head1 CONTRIBUTING
 
-This project is managed using the darcs source control system (
-http://www.darcs.net/ ). My darcs archive is here:
+Patches, questions and feedback are welcome. This project is managed using
+the darcs source control system ( http://www.darcs.net/ ). My darcs archive is here:
 http://mark.stosberg.com/darcs_hive/dfv/
 
-B<Support Mailing List>
- 
-If you have any questions, comments, or feature suggestions, post them to the
-support mailing list!  To join the mailing list, visit
-
-L<http://lists.sourceforge.net/lists/listinfo/cascade-dataform>
-
-Messages about DFV sent directly to the maintainer may be redirected here. 
-
 =head1 AUTHOR
 
-Parts Copyright 2001-2006 by Mark Stosberg <mark at summersault.com>, (Current Maintainer)
+Parts Copyright 2001-2003 by Mark Stosberg <markstos@cpan.org>, (Current Maintainer)
 
 Copyright (c) 1999 Francis J. Lacoste and iNsu Innovations Inc.  All rights reserved.
 (Original Author)
@@ -1225,6 +1165,12 @@ Parts Copyright 1996-1999 by Michael J. Heins <mike@heins.net>
 
 Parts Copyright 1996-1999 by Bruce Albrecht  <bruce.albrecht@seag.fingerhut.com>
 
+B<Support Mailing List>
+ 
+If you have any questions, comments, bug reports or feature suggestions,
+post them to the support mailing list!  To join the mailing list, visit 
+L<http://lists.sourceforge.net/lists/listinfo/cascade-dataform>
+
 =head1 LICENSE 
 
 This program is free software; you can redistribute it and/or modify
@@ -1232,4 +1178,3 @@ it under the terms as perl itself.
 
 =cut
 
-
