@@ -23,13 +23,17 @@ package Data::FormValidator::Constraints;
 use strict;
 use vars qw/$AUTOLOAD @ISA @EXPORT_OK %EXPORT_TAGS $VERSION/;
 
-$VERSION = 4.21_01;
+$VERSION = 4.00;
 
 require Exporter;
 @ISA = qw(Exporter);
 
 BEGIN {
+    # A gift from Andy Lester, this trick shows me where eval's die. 
     use Carp;
+    $SIG{__WARN__} = \&carp;
+    $SIG{__DIE__} = \&confess;
+
     my @closures = (qw/
         american_phone
         cc_exp
@@ -53,7 +57,6 @@ BEGIN {
             # Notice we have to escape some characters
             # in the subroutine, which is really a string here. 
 
-            local $SIG{__DIE__} = \&confess;
             my $code = qq!
             sub $func  {
                 return sub {
@@ -77,9 +80,6 @@ BEGIN {
     @EXPORT_OK = (
         @closures,
         qw(
-        FV_length_between
-        FV_min_length
-        FV_max_length
         valid_american_phone
         valid_cc_exp
         valid_cc_number
@@ -165,8 +165,7 @@ BEGIN {
 
                         no strict "refs";
                         my $re = &$sub(-keep=>1,@params);
-                        my ($match) = ($dfv->get_current_constraint_value =~ qr/^($re)$/);
-                        return $dfv->untainted_constraint_value($match);
+                        return ($dfv->get_current_constraint_value =~ qr/^$re$/) ? $1 : undef; 
                     }
                 }
             }
@@ -228,76 +227,11 @@ sub AUTOLOAD {
     }
 }
 
-=head2 FV_length_between(1,23) 
+=pod
 
-=head2 FV_max_length(23)
+=over 
 
-=head2 FV_min_length(1)
-
-  use Data::FormValidator::Constraints qw(
-    FV_length_between
-    FV_min_length
-    FV_max_length
-  );
-
-  constraint_methods => {
-
-    # specify a min and max, inclusive
-    last_name        => FV_length_between(1,23),
-
-  }
-
-Specify a length constraint for a field. 
-
-These constraints have a different naming convention because they are higher-order
-functions. They take input and return a code reference to a standard constraint
-method. A constraint name of C<length_between>, C<min_length>, or C<max_length> will be set,
-corresponding to the function name you choose. 
-
-The checks are all inclusive, so a max length of '100' will allow the length 100. 
-
-This constraint I<will> untaint your data if you have untainting turned on. However,
-a length check alone may not be enough to insure the safety of the data you are receiving.
-Using additional constraints to check the data is encouraged. 
-
-=cut
-
-sub FV_length_between {
-    my ($min,$max) = @_;
-    if (not (defined $min and defined $max)) {
-            croak "min and max are required";
-    }
-    return sub {
-        my ($dfv,$value) = @_;
-        $dfv->name_this('length_between');
-        my ($match) = ($value =~ m/^(.{$min,$max})$/);
-        return $dfv->untainted_constraint_value($match);
-    }
-}
-
-sub FV_max_length {
-    my ($max) = @_;
-    croak "max is required" unless defined $max;
-    return sub {
-        my ($dfv,$value) = @_;
-        $dfv->name_this('max_length');
-        my ($match) = ($value =~ m/^(.{0,$max}$)/);
-        return $dfv->untainted_constraint_value($match);
-    }
-}
-
-sub FV_min_length {
-    my ($min) = @_;
-    croak "min is required" unless defined $min;
-    return sub {
-        my ($dfv,$value) = @_;
-        $dfv->name_this('min_length');
-        my ($match) = ($value =~ m/^(.{$min,})$/);
-        return $dfv->untainted_constraint_value($match);
-    }
-}
-
-=head2 email
+=item email
 
 Checks if the email LOOKS LIKE an email address. This should be sufficient
 99% of the time. 
@@ -332,7 +266,9 @@ my $province = <<EOF;
 AB BC MB NB NF NL NS NT NU ON PE QC SK YT YK
 EOF
 
-=head2 state_or_province
+=pod
+
+=item state_or_province
 
 This one checks if the input correspond to an american state or a canadian
 province.
@@ -349,10 +285,12 @@ sub match_state_or_province {
 	}
 }
 
-=head2 state
+=pod
+
+=item state
 
 This one checks if the input is a valid two letter abbreviation of an 
-American state.
+american state.
 
 =cut
 
@@ -364,9 +302,11 @@ sub match_state {
     else { return undef; }
 }
 
-=head2 province
+=pod
 
-This checks if the input is a two letter Canadian province
+=item province
+
+This checks if the input is a two letter canadian province
 abbreviation.
 
 =cut
@@ -379,10 +319,12 @@ sub match_province {
     else { return undef; }
 }
 
-=head2 zip_or_postcode
+=pod
 
-This constraints checks if the input is an American zipcode or a
-Canadian postal code.
+=item zip_or_postcode
+
+This constraints checks if the input is an american zipcode or a
+canadian postal code.
 
 =cut
 
@@ -397,7 +339,7 @@ sub match_zip_or_postcode {
 }
 =pod
 
-=head2 postcode
+=item postcode
 
 This constraints checks if the input is a valid Canadian postal code.
 
@@ -412,7 +354,9 @@ sub match_postcode {
     else { return undef; }
 }
 
-=head2 zip
+=pod
+
+=item zip
 
 This input validator checks if the input is a valid american zipcode :
 5 digits followed by an optional mailbox number.
@@ -427,7 +371,9 @@ sub match_zip {
     else { return undef; }
 }
 
-=head2 phone
+=pod
+
+=item phone
 
 This one checks if the input looks like a phone number, (if it
 contains at least 6 digits.)
@@ -443,7 +389,9 @@ sub match_phone {
     else { return undef; }
 }
 
-=head2 american_phone
+=pod
+
+=item american_phone
 
 This constraints checks if the number is a possible North American style
 of phone number : (XXX) XXX-XXXX. It has to contains 7 or more digits.
@@ -460,7 +408,9 @@ sub match_american_phone {
 }
 
 
-=head2 cc_number
+=pod
+
+=item cc_number
 
 This constraint references the value of a credit card type field.
 
@@ -481,24 +431,16 @@ CHECK IF THERE IS AN ACCOUNT ASSOCIATED WITH THE NUMBER.
 # This one is taken from the contributed program to 
 # MiniVend by Bruce Albrecht
 
-# XXX raise exception on bad/missing params?
 sub cc_number {
-    my $attrs = shift; 
-    return undef unless $attrs && ref($attrs) eq 'HASH'
-      && exists $attrs->{fields} && ref($attrs->{fields}) eq 'ARRAY';
+	my $dfv = shift;
+	my $attrs = pop; 
+	my $data = $dfv->get_input_data;
 
-    my ($cc_type_field) = @{ $attrs->{fields} };
-    return undef unless $cc_type_field;
-
-    return sub {
-        my $dfv = shift;
-        my $data = $dfv->get_input_data;
-
-        return match_cc_number( 
-            $dfv->get_current_constraint_value,
-            $data->{$cc_type_field}
-        );
-    };
+	my ($cc_type_field) = @{ $attrs->{fields} };
+	return match_cc_number( 
+		$dfv->get_current_constraint_value,
+		$data->{$cc_type_field}
+	);
 }
 
 sub match_cc_number {
@@ -552,7 +494,9 @@ sub match_cc_number {
     }
 }
 
-=head2 cc_exp
+=pod
+
+=item cc_exp
 
 This one checks if the input is in the format MM/YY or MM/YYYY and if
 the MM part is a valid month (1-12) and if that date is not in the past.
@@ -579,7 +523,9 @@ sub match_cc_exp {
     return "$matched_month/$matched_year";
 }
 
-=head2 cc_type
+=pod
+
+=item cc_type
 
 This one checks if the input field starts by M(asterCard), V(isa),
 A(merican express) or D(iscovery).
@@ -592,12 +538,11 @@ sub match_cc_type {
     else { return undef; }
 }
 
-=head2 ip_address
+=pod
 
-This checks if the input is formatted like a dotted decimal IP address (v4).
-For other kinds of IP address method, See L<Regexp::Common::net> which provides 
-several more options. L<REGEXP::COMMON SUPPORT> explains how we easily integrate
-with Regexp::Common. 
+=item ip_address
+
+This checks if the input is formatted like an IP address (v4)
 
 =cut
 
@@ -620,6 +565,10 @@ sub match_ip_address {
 
 __END__
 
+=pod
+
+=back
+
 =head1 REGEXP::COMMON SUPPORT
 
 Data::FormValidator also includes built-in support for using any of regular expressions
@@ -692,7 +641,7 @@ This is the current recommended way to write constraints. See also L<Old School
 Constraints>.
 
 The most flexible way to create constraints to use closures-- a normal seeming
-outer subroutine which returns a customized DFV method subroutine as a result.
+outer subroutine which returins a customized DFV method subroutine as a result.
 It's easy to do. These "constraint methods" can be named whatever you like, and
 imported normally into the name space where the profile is located. 
 
@@ -784,7 +733,9 @@ with C<constraint_regexp_map>.
 A few useful methods to use on the Data::FormValidator::Results object are
 available to you to use inside of your routine.
 
-=head3 get_input_data()
+=over 4
+
+=item get_input_data()
 
 Returns the raw input data. This may be a CGI object if that's what 
 was used in the constraint routine. 
@@ -797,7 +748,7 @@ B<Examples:>
  # tamed to be a hashref, if it wasn't already
  my $data = $self->get_input_data( as_hashref => 1 );
 
-=head3 get_current_constraint_field()
+=item get_current_constraint_field
 
 Returns the name of the current field being tested in the constraint.
 
@@ -810,7 +761,7 @@ and allows multi-valued constraints to be used with C<constraint_regexp_map>.
 
 For complete examples of multi-valued constraints, see L<Data::FormValidator::Constraints::Upload>
 
-=head3 get_current_constraint_value()
+=item get_current_constraint_value
 
 Returns the name of the current value being tested in the constraint.
 
@@ -821,7 +772,7 @@ B<Example>:
 This reduces the number of parameters that need to be passed into the routine
 and allows multi-valued constraints to be used with C<constraint_regexp_map>.
 
-=head3 get_current_constraint_name()
+=item get_current_constraint_name
 
 Returns the name of the current constraint being applied
 
@@ -829,21 +780,12 @@ B<Example>:
 
  my $value = $self->get_current_constraint_name;
 
-This is useful for building a constraint on the fly based on its name.
+This is useful for building a constraint on the fly based on it's name.
 It's used internally as part of the interface to the L<Regexp::Commmon>
 regular expressions.
 
-=head3 untainted_constaint_value()
-
-   return $dfv->untainted_constraint_value($match);
-
-If you have written a constraint which untaints, use this method to return the
-untainted result. It will prepare the right result whether the user has requested
-untainting or not. 
-
-=head3 name_this()
-
-=head3 set_current_constraint_name()
+=item name_this
+=item set_current_constraint_name
 
 Sets the name of the current constraint being applied.
 
@@ -866,6 +808,8 @@ example.
 
 C<name_this> is a provided as a shorter synonym.
 
+=back
+
 The C<meta()> method may also be useful to communicate meta data that
 may have been found. See L<Data::FormValidator::Results> for documentation
 of that method.
@@ -897,31 +841,16 @@ and the names were given as strings, like this:
 
 =head1 SEE ALSO
 
-=head2 Constraints available in other modules
+L<Data::FormValidator::Constraints::Upload> - validate the bytes, format and dimensions of file uploads,
+L<Data::FormValidator::Constraints::DateTime> - 
+  A newer DateTime constraint module. May save you a step of tranforming the date into
+  a more useful format after it's validated. 
+L<Data::FormValidator::Constraints::Dates> - the original DFV date constraint module
+L<Regexp::Common> -- lost of useful regular expressions to choose from!
 
-=over
-
-=item L<Data::FormValidator::Constraints::Upload> - validate the bytes, format and dimensions of file uploads
-
-=item L<Data::FormValidator::Constraints::DateTime> - A newer DateTime constraint module. May save you a step of tranforming the date into a more useful format after it's validated. 
-
-=item L<Data::FormValidator::Constraints::Dates> - the original DFV date constraint module. Try the newer one first!
-
-=item L<Data::FormValidator::Constraints::Japanese> - Japan-specific constraints
-
-=back
-
-=head2 Related modules in this package
-
-=over
-
-=item L<Data::FormValidator::Filters> - transform data before constraints are applied
-
-=item L<Data::FormValidator::ConstraintsFactory> - This is a historical collection of constraints that suffer from cumbersome names. They are worth reviewing though-- C<make_and_constraint> will allow to validate against a list of constraints and shortcircuit if the first one fails. That's perfect if the second constraint depends on the first one having passed.
-
-=item L<Data::FormValidator>
-
-=back
+L<Data::FormValidator>
+L<Data::FormValidator::Filters>
+L<Data::FormValidator::ConstraintsFactory>
 
 =head1 CREDITS
 
