@@ -15,16 +15,14 @@ use strict;
 
 package Data::FormValidator::Results;
 
-use Carp;
 use Symbol;
-use Data::FormValidator::Filters ':filters';
-use Data::FormValidator::Constraints qw(:validators :matchers);
+use Data::FormValidator::Filters qw/:filters/;
+use Data::FormValidator::Constraints (qw/:validators :matchers/);
 use vars qw/$AUTOLOAD $VERSION/;
 use overload
-  'bool' => \&_bool_overload_based_on_success,
-  fallback => 1;
+  'bool' => \&_bool_overload_based_on_success;
 
-$VERSION = 4.49_01;
+$VERSION = 4.01;
 
 =pod
 
@@ -46,7 +44,7 @@ Data::FormValidator::Results - results of form input validation.
     # Print the name of invalid fields
     if ( $results->has_invalid ) {
 	foreach my $f ( $results->invalid ) {
-	    print $f, " is invalid: ", $results->invalid( $f ), "\n";
+	    print $f, " is invalid: ", $results->invalid( $f ) \n";
 	}
     }
 
@@ -59,7 +57,7 @@ Data::FormValidator::Results - results of form input validation.
 
     # Print valid fields
     foreach my $f ( $results->valid() ) {
-        print $f, " =  ", $results->valid( $f ), "\n";
+	print $f, " =  ", $result->valid( $f ), "\n";
     }
 
 =head1 DESCRIPTION
@@ -99,7 +97,6 @@ sub _process {
     # import valid_* subs from requested packages
 	foreach my $package (_arrayify($profile->{validator_packages})) {
 		if ( !exists $imported_validators{$package} ) {
-			local $SIG{__DIE__}  = \&confess;
 			eval "require $package";
 			if ($@) {
 				die "Couldn't load validator package '$package': $@";
@@ -200,7 +197,7 @@ sub _process {
 		if (ref $valid{$field}) {
 			if ( ref $valid{$field} eq 'ARRAY' ) {
 				for (my $i = 0; $i < scalar @{ $valid{$field} }; $i++) {
-					$valid{$field}->[$i] = undef unless (defined $valid{$field}->[$i] and length $valid{$field}->[$i] and $valid{$field}->[$i] !~ /^\x00$/);
+					$valid{$field}->[$i] = undef unless (defined $valid{$field}->[$i] and length $valid{$field}->[$i]);
 			    }	
                 # If all fields are empty, we delete it.
                 delete $valid{$field} unless grep { defined $_ } @{$valid{$field}};
@@ -208,13 +205,13 @@ sub _process {
 			}
 		}
 		else {
-			delete $valid{$field} unless (defined $valid{$field} and length $valid{$field} and $valid{$field} !~ /^\x00$/);
+			delete $valid{$field} unless (defined $valid{$field} and length $valid{$field});
 		}
 	}
 
     # Check if the presence of some fields makes other optional fields required.
     while ( my ( $field, $deps) = each %{$profile->{dependencies}} ) {
-        if (defined $valid{$field}) {
+        if ($valid{$field}) {
 			if (ref($deps) eq 'HASH') {
 				foreach my $key (keys %$deps) {
                     # Handle case of a key with a single value given as an arrayref
@@ -262,22 +259,8 @@ sub _process {
 		delete $valid{$field};
 	}
 
-    # Add defaults from defaults_regexp_map
-    my %private_defaults;
-    my @all_possible = keys %optional, keys %required, keys %require_some;
-    while ( my ($re,$value) = each %{$profile->{defaults_regexp_map}} ) {
-        # We only add defaults for known fields. 
-        for (@all_possible) {
-            $private_defaults{$_} = $value if m/$re/;
-        }
-    }
-
     # Fill defaults
-    my %combined_defaults = ( 
-        %private_defaults, 
-        %{ $profile->{defaults} || {} } 
-    );
-    while ( my ($field,$value) = each %combined_defaults ) {
+    while ( my ($field,$value) = each %{$profile->{defaults}} ) {
         unless(exists $valid{$field}) {
             if (ref($value) && ref($value) eq "CODE") {
                 $valid{$field} = $value->($self);
@@ -304,6 +287,23 @@ sub _process {
 		push @missings, $field unless ($enough_required_fields >= $num_fields_to_require);
 	}
 
+    #Decide which fields to untaint
+    my ($untaint_all, %untaint_hash);
+	if (defined($profile->{untaint_constraint_fields})) {
+		if (ref $profile->{untaint_constraint_fields} eq "ARRAY") {
+			foreach my $field (@{$profile->{untaint_constraint_fields}}) {
+				$untaint_hash{$field} = 1;
+			}
+		}
+		elsif ($valid{$profile->{untaint_constraint_fields}}) {
+			$untaint_hash{$profile->{untaint_constraint_fields}} = 1;
+		}
+	}
+    elsif ((defined($profile->{untaint_all_constraints}))
+	   && ($profile->{untaint_all_constraints} == 1)) {
+	   $untaint_all = 1;
+    }
+
     # add in the constraints from the regexp maps
     # We don't want to modify the profile, so we use a new variable.
 	$profile->{constraints} ||= {};
@@ -317,45 +317,6 @@ sub _process {
 		_add_constraints_from_map($profile,'constraint_method',\%valid),
 	};
 
-    #Decide which fields to untaint
-    my ($untaint_all, %untaint_hash);
-    if (defined $profile->{untaint_regexp_map} or defined $profile->{untaint_constraint_fields} ) {
-        # first deal with untaint_constraint_fields
-        if (defined($profile->{untaint_constraint_fields})) {
-            if (ref $profile->{untaint_constraint_fields} eq "ARRAY") {
-                foreach my $field (@{$profile->{untaint_constraint_fields}}) {
-                    $untaint_hash{$field} = 1;
-                }
-            }
-            elsif ($valid{$profile->{untaint_constraint_fields}}) {
-                $untaint_hash{$profile->{untaint_constraint_fields}} = 1;
-            }
-        }
-
-        # now look at untaint_regexp_map
-        if(defined($profile->{untaint_regexp_map})) {
-            my @untaint_regexes;
-            if(ref $profile->{untaint_regexp_map} eq "ARRAY") {
-                @untaint_regexes = @{$profile->{untaint_regexp_map}};
-            }
-            else {
-                push(@untaint_regexes, $profile->{untaint_regexp_map});
-            }
-
-            foreach my $regex (@untaint_regexes) {
-                # look at both constraints and constraint_methods
-                foreach my $field (keys %$private_constraints, keys %$private_constraint_methods) {
-                    next if($untaint_hash{$field}); 
-                    $untaint_hash{$field} = 1 if( $field =~ $regex );
-                }
-            }
-        }
-    }
-    elsif ((defined($profile->{untaint_all_constraints}))
-	   && ($profile->{untaint_all_constraints} == 1)) {
-	   $untaint_all = 1;
-    }
-
 	$self->_check_constraints($private_constraints,\%valid,$untaint_all,\%untaint_hash);
 
 	my $force_method_p = 1;
@@ -556,17 +517,11 @@ This method returns a hash reference to error messages. The exact format
 is determined by parameters in the C<msgs> area of the validation profile,
 described in the L<Data::FormValidator> documentation.
 
-B<NOTE:> the C<msgs> parameter in the profile can take a code reference as a
-value, allowing complete control of how messages are generated. If such a code
-reference was provided there, it will be called here instead of the usual
-processing, described below. It will receive as arguments the L<Data::FormValidator::Results>
-object and a hash reference of control parameters.
-
-The hashref passed in should contain the same options that you can define in
-the validation profile. This allows you to separate the controls for message
-display from the rest of the profile. While validation profiles may be
-different for every form, you may wish to format messages the same way across
-many projects.
+This method takes one possible parameter, a hash reference containing the same 
+options that you can define in the validation profile. This allows you to separate
+the controls for message display from the rest of the profile. While validation profiles
+may be different for every form, you may wish to format messages the same way
+across many projects.
 
 Controls passed into the <msgs> method will be applied first, followed by ones
 applied in the profile. This allows you to keep the controls you pass to
@@ -575,17 +530,6 @@ C<msgs> as "global" and override them in a specific profile if needed.
 =cut
 
 sub msgs {
-  my $self = shift;
-  my $msgs = $self->{profile}{msgs} || {};
-  if ((ref $msgs eq 'CODE')) {
-    return $msgs->($self,@_);
-  } else {
-    return $self->_generate_msgs(@_);
-  }
-}
-
-
-sub _generate_msgs {
 	my $self = shift;
 	my $controls = shift || {};
 	if (defined $controls and ref $controls ne 'HASH') {
@@ -644,9 +588,7 @@ sub _generate_msgs {
 
 	my $msgs_ref = prefix_hash($profile{prefix},\%msgs);
 
-    if (! $self->success) {
-    	$msgs_ref->{ $profile{any_errors} } = 1 if defined $profile{any_errors};
-    }
+	$msgs_ref->{ $profile{any_errors} } = 1 if defined $profile{any_errors};
 
 	return $msgs_ref;
 
@@ -739,14 +681,6 @@ sub get_current_constraint_name {
 	return $self->{__CURRENT_CONSTRAINT_NAME};
 }
 
-sub untainted_constraint_value {
-    my $self = shift;
-    my $match = shift;
-
-    return undef unless defined $match;
-    return $self->{__UNTAINT_THIS} ? $match : length $match;
-}
-
 sub set_current_constraint_name {
 	my $self = shift;
 	my $value = shift;
@@ -781,14 +715,12 @@ sub prefix_hash {
 sub _create_sub_from_RE {
 	my $re = shift || return undef;
 	my $untaint_this = shift;
-    my $force_method_p = shift;
 
 	my $sub;
 	# If it's "qr" style
 	if (substr($re,0,1) eq '(') {
 		$sub = sub { 
-            # With methods, the value is the second argument
-            my $val = $force_method_p ? $_[1] : $_[0];
+            my $val = shift;
 			my ($match) = ($val =~ $re); 
 			if ($untaint_this && defined $match) {
                 # pass the value through a RE that matches anything to untaint it.
@@ -802,22 +734,15 @@ sub _create_sub_from_RE {
 
 	}
 	else {
-        local $SIG{__DIE__}  = \&confess;
         my $return_code = ($untaint_this) ? '; return ($& =~ m/(.*)/s)[0] if defined($`);' : '';
-        # With methods, the value is the second argument
-        if ($force_method_p) {
-            $sub = eval 'sub { $_[1] =~ '.$re.$return_code. '}';
-        }
-        else {
-            $sub = eval 'sub { $_[0] =~ '.$re.$return_code. '}';
-        }
+		$sub = eval 'sub { $_[0] =~ '.$re.$return_code. '}';
 	    die "Error compiling regular expression $re: $@" if $@;
 	}
 	return $sub;
 }
 
 
-sub _error_msg_fmt  {
+sub _error_msg_fmt ($$) {
 	my ($fmt,$msg) = @_;
 	$fmt ||= 
 			'<span style="color:red;font-weight:bold"><span class="dfv_errors">* %s</span></span>';
@@ -865,9 +790,8 @@ sub _filter_apply {
 # $constraint_href = $self->_constraint_hash_build($spec,$untaint_p)
 #
 # Input:
-#   - $spec           # Any constraint valid in the profile
-#   - $untaint        # bool for whether we could try to untaint the field. 
-#   - $force_method_p # bool for if it's  a method ?
+#   - $spec     # Any constraint valid in the profile
+#   - $untaint  # bool for whether we could try to untaint the field. 
 #
 # Output:
 #  - $constraint_hashref
@@ -878,8 +802,8 @@ sub _filter_apply {
 # 		is_method  - bool for whether this was a 'constraint' or 'constraint_method'
 
 sub _constraint_hash_build {
-	my ($self,$constraint_spec,$untaint_this,$force_method_p) = @_;
-	die "_constraint_hash_build received wrong number of arguments" unless (scalar @_ == 4);
+	my ($self,$constraint_spec,$untaint_this) = @_;
+	die "_constraint_hash_build received wrong number of arguments" unless (scalar @_ == 3);
 
 	my	$c = {
 			name 		=> $constraint_spec,
@@ -897,7 +821,7 @@ sub _constraint_hash_build {
 	# Check for regexp constraint
 	if ((ref $c->{constraint} eq 'Regexp')
 			or ( $c->{constraint} =~ m@^\s*(/.+/|m(.).+\2)[cgimosx]*\s*$@ )) {
-		$c->{constraint} = _create_sub_from_RE($c->{constraint},$untaint_this,$force_method_p);
+		$c->{constraint} = _create_sub_from_RE($c->{constraint},$untaint_this);
 	}
 	# check for code ref
 	elsif (ref $c->{constraint} eq 'CODE') {
@@ -916,7 +840,6 @@ sub _constraint_hash_build {
 			}
 			# If the constraint name starts with RE_, try looking for it in the Regexp::Common package
 			elsif ($c->{constraint} =~ m/^RE_/) {
-				local $SIG{__DIE__}  = \&confess;
 				$c->{is_method} = 1;
 				$c->{constraint} = eval 'sub { &_create_regexp_common_constraint(@_)}' 
 					|| die "could not create Regexp::Common constraint: $@";
@@ -928,7 +851,6 @@ sub _constraint_hash_build {
 			# try to use match_* first
 			my $routine = 'match_'.$c->{constraint};			
 			if (defined *{qualify_to_ref($routine)}{CODE}) {
-				local $SIG{__DIE__}  = \&confess;
 				$c->{constraint} = eval 'sub { no strict qw/refs/; return defined &{"match_'.$c->{constraint}.'"}(@_)}';
 			}
 			# match_* doesn't exist; if it is supposed to be from the
@@ -938,7 +860,6 @@ sub _constraint_hash_build {
 			}
 			# Load it from Regexp::Common 
 			elsif ($c->{constraint} =~ m/^RE_/) {
-				local $SIG{__DIE__}  = \&confess;
 				$c->{is_method} = 1;
 				$c->{constraint} = eval 'sub { return defined &_create_regexp_common_constraint(@_)}' ||
 					die "could not create Regexp::Common constraint: $@";
@@ -1004,10 +925,6 @@ sub _constraint_check_match {
 	my 	($self,$c,$params,$untaint_this) = @_;
 	die "_constraint_check_match received wrong number of arguments" unless (scalar @_ == 4);
 
-    # Store whether or not we want untainting in the object so that constraints
-    # can do the right thing conditionally.
-    $self->{__UNTAINT_THIS} = $untaint_this;
-
     my $match = $c->{constraint}->( @$params );
 
     # We need to make this distinction when untainting,
@@ -1046,14 +963,7 @@ sub _get_input_as_hash {
 	}
 	# otherwise, it's already a hash reference
     elsif (ref $data eq 'HASH') {
-        # be careful to actually copy array references
-        my %copy = %$data;
-        for (grep { ref $data->{$_} eq 'ARRAY' } keys %$data) {
-            my @array_copy = @{ $data->{$_} };
-            $copy{$_} = \@array_copy;
-        }
-
-		return %copy;
+		return %$data;	
     }
 	else {
 		die "Data::FormValidator->validate() or check() called with invalid input data structure.";
@@ -1123,7 +1033,7 @@ sub _add_constraints_from_map {
 					else {
 						$result{$key} = $new;
 					}
-					warn "$map_name: $key matches\n" if $profile->{debug};
+					warn "constraint_regexp_map: $key matches\n" if $profile->{debug};
 				}
 			}
 	}
@@ -1164,11 +1074,9 @@ sub _check_constraints {
 		next unless exists $valid->{$field};
 
 		my $is_constraint_list = 1 if (ref $constraint_list eq 'ARRAY');
-		my $untaint_this = ($untaint_all || $untaint_href->{$field} || 0);
+		my $untaint_this =  ($untaint_all || $untaint_href->{$field} || 0);
 
 		my @invalid_list;
-        # used to insure we only bother recording each failed constraint once
-		my %constraints_seen;
 		foreach my $constraint_spec (_arrayify($constraint_list)) {
 
 			# set current constraint field for use by get_current_constraint_field
@@ -1178,29 +1086,25 @@ sub _check_constraints {
 			# from being accidently shared
 			$self->{__CURRENT_CONSTRAINT_NAME} = undef;
 
-			my $c = $self->_constraint_hash_build($constraint_spec,$untaint_this, $force_method_p);
+			my $c = $self->_constraint_hash_build($constraint_spec,$untaint_this);
 			$c->{is_method} = 1 if $force_method_p;
 
 			my $is_value_list = 1 if (ref $valid->{$field} eq 'ARRAY');
             my %param_data = ( $self->_get_input_as_hash($self->get_input_data) , %$valid );
 			if ($is_value_list) {
 				foreach (my $i = 0; $i < scalar @{ $valid->{$field}} ; $i++) {
-                    if( !exists $constraints_seen{\$c} ) {
+					my @params = $self->_constraint_input_build($c,$valid->{$field}->[$i],\%param_data);
 
-                        my @params = $self->_constraint_input_build($c,$valid->{$field}->[$i],\%param_data);
+					# set current constraint field for use by get_current_constraint_value
+					$self->{__CURRENT_CONSTRAINT_VALUE} = $valid->{$field}->[$i];
 
-                        # set current constraint field for use by get_current_constraint_value
-                        $self->{__CURRENT_CONSTRAINT_VALUE} = $valid->{$field}->[$i];
-
-                        my ($match,$failed) = $self->_constraint_check_match($c,\@params,$untaint_this);
-                        if ($failed->{failed}) {
-                            push @invalid_list, $failed;
-                            $constraints_seen{\$c} = 1;
-                        }
-                        else {
-                            $valid->{$field}->[$i] = $match if $untaint_this;
-                        }
-                    }
+					my ($match,$failed) = $self->_constraint_check_match($c,\@params,$untaint_this);
+					if ($failed->{failed}) {
+						push @invalid_list, $failed;
+					}
+					else {
+						 $valid->{$field}->[$i] = $match if $untaint_this;
+					}
 				}
 			}
 			else {
